==> kdav2-0.2.0.tar.xz: kdav2-0.2.0/src/common/davcollectiondeletejob.cpp <==
/*
    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "davcollectiondeletejob.h"

#include "daverror.h"
#include "davjob.h"
#include "davmanager.h"

using namespace KDAV2;

DavCollectionDeleteJob::DavCollectionDeleteJob(const DavUrl &url, QObject *parent)
    : DavJobBase(parent), mUrl(url)
{
}

void DavCollectionDeleteJob::start()
{
    DavJob *job = DavManager::self()->createDeleteJob(mUrl.url());
    connect(job, &DavJob::result, this, &DavCollectionDeleteJob::davJobFinished);
}

void DavCollectionDeleteJob::davJobFinished(KJob *job)
{
    auto *deleteJob = qobject_cast<DavJob*>(job);

    //TODO Ignore deleteJob->error() != KIO::ERR_NO_CONTENT
    if (deleteJob->error()) {
        const int responseCode = deleteJob->responseCode();

        setLatestResponseCode(responseCode);
        setError(ERR_COLLECTIONDELETE);
        setJobErrorText(deleteJob->errorText());
        setJobError(deleteJob->error());
        setErrorTextFromDavError();
    }

    emitResult();
}

==> kdav2-0.3.0.tar.xz: kdav2-0.3.0/src/common/davcollectiondeletejob.cpp <==
/*
    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "davcollectiondeletejob.h"

#include "daverror.h"
#include "davjob.h"
#include "davmanager.h"

using namespace KDAV2;

DavCollectionDeleteJob::DavCollectionDeleteJob(const DavUrl &url, QObject *parent)
    : DavJobBase(parent), mUrl(url)
{
}

void DavCollectionDeleteJob::start()
{
    DavJob *job = DavManager::self()->createDeleteJob(mUrl.url());
    connect(job, &DavJob::result, this, &DavCollectionDeleteJob::davJobFinished);
}

void DavCollectionDeleteJob::davJobFinished(KJob *job)
{
    auto *deleteJob = qobject_cast<DavJob*>(job);

    //TODO Ignore deleteJob->error() != KIO::ERR_NO_CONTENT
    if (deleteJob->error()) {
        setErrorFromJob(deleteJob, ERR_COLLECTIONDELETE);
    }

    emitResult();
}
